// A demonstration of reading an animated GIF into an array
// of PImages.  Load a GIF and draw a tiled view of each of 
// its frames.

import gifAnimation.*;

PImage[] imgs;
// Decide the width at which we plan to show each frame.
int iw = 80;
// We'll compute the height of each frame proportionally
// based on the size of the actual GIF.
int ih;

void setup()
{
  // Open a cat video, duh.
  imgs = Gif.getPImages( this, "catfail.gif" );
  int w = imgs[0].width;
  int h = imgs[0].height;
  // Based on the aspect ration of the GIF, compute ih from iw.
  // This is a bit mathematical, but pretty standard in 
  // computer graphics.  If you try a few examples, you'll
  // see why it works.
  ih = int( iw * float( h ) / float( w ) );
  
  // Set the size of the sketch window to be tall enough 
  // to hold all the frames in the GIF.
  size( 800, int( ceil( imgs.length / 10.0 ) ) * ih );
}

void draw()
{
  // Draw all the frames in a grid arrangement.
  for( int idx = 0; idx < imgs.length; ++idx ) {
    // % and / can be used together, as below, to turn
    // a linear array index into grid coordinates.
    int x = (idx % 10) * iw;
    int y = (idx / 10) * ih;
    image( imgs[idx], x, y, iw, ih );
  }
  // No need to keep drawing.
  noLoop();
}
