import processing.pdf.*;

int n;
boolean record;

void setup()
{
  size( 500, 500 );
  n = 50;
  record = false;
}

void draw()
{
  // If it's time to record then set things up to save a copy
  // to the file.
  if( record ) {
    beginRecord( PDF, "output.pdf" );
  }
  
  background( 255 );
  stroke( 0 );
  strokeWeight( 0.5 );
  noFill();
  
  // These don't have to be anything in particular, it
  // just gives the sketch some interesting motion.
  float ang1 = -millis() / 1000.0;
  float ang2 = millis() / 1000.0 * 1.1 + 1.0;
  
  for( int idx = 0; idx < n; ++idx ) {
    float t = float(idx)/float(n);
    float x1 = lerp( width/2, width/2 + 200*cos(ang1), t );
    float y1 = lerp( height/2, height/2 + 200*sin(ang1), t );
    float x2 = lerp( width/2, width/2 + 200*cos(ang2), 1-t );
    float y2 = lerp( height/2, height/2 + 200*sin(ang2), 1-t );
    line( x1, y1, x2, y2 );
  }
  
  // We were recording?  If so, time to stop.  Make sure
  // to set record back to false, or we'll keep re-recording
  // the PDF every frame.
  if( record ) {
    endRecord();
    record = false;
  }
}

// A pretty standard idiom for writing PDFs in Processing.
// Wait for a key press, and if they right key is detected
// then set a variable that will be read in the next pass
// through the draw() function.
void keyPressed()
{
  if( key == ' ' ) {
    record = true;
  }
}
